==> aioqsw-0.1.2.tar.gz: aioqsw-0.1.2/aioqsw/const.py <==
"""QNAP QSW library constants."""

API_ANOMALY = "anomaly"
API_AUTHORIZATION = "Authorization"
API_BUILD_NUMBER = "buildNumber"
API_CHIP_ID = "ChipId"
API_CI_BRANCH = "ci_branch"
API_CI_COMMIT = "ci_commit"
API_CI_PIPELINE = "ci_pipeline"
API_COMMAND = "command"
API_COMMIT_CPSS = "commit_cpss"
API_COMMIT_ISS = "commit_iss"
API_DATE = "date"
API_DESCRIPTION = "description"
API_DOWNLOAD_URL = "downloadURL"
API_ERROR_CODE = "error_code"
API_ERROR_MESSAGE = "error_message"
API_FAN1_SPEED = "Fan1Speed"
API_FAN2_SPEED = "Fan2Speed"
API_LIVE = "live"
API_MAC_ADDR = "MacAddr"
API_MAX_SWITCH_TEMP = "MaxSwitchTemp"
API_MESSAGE = "message"
API_MODEL = "Model"
API_NEWER = "newer"
API_NUMBER = "number"
API_PASSWORD = "password"
API_QSW_ID = "QSW_ID"
API_QSW_LANG = "QSW_LANG"
API_PATH = "api"
API_PATH_V1 = "api/v1"
API_PRODUCT = "Product"
API_PORT_NUM = "PortNum"
API_PUB_DATE = "pubDate"
API_REBOOT = "reboot"
API_RESULT = "result"
API_SERIAL = "SerialNumber"
API_SWITCH_TEMP = "SwitchTemp"
API_TRUNK_NUM = "TrunkNum"
API_UPTIME = "UpTime"
API_USERNAME = "username"
API_VERSION = "version"

API_ERROR_PARSING_FAILED = 6

QSD_ANOMALY = "anomaly"
QSD_BUILD_NUMBER = "build-number"
QSD_CHIP_ID = "chip-id"
QSD_CI_BRANCH = "ci-branch"
QSD_CI_COMMIT = "ci-commit"
QSD_CI_PIPELINE = "ci-pipeline"
QSD_COMMIT_CPSS = "commit-cpss"
QSD_COMMIT_ISS = "commit-iss"
QSD_DATE = "date"
QSD_DESCRIPTION = "description"
QSD_DOWNLOAD_URLS = "download-urls"
QSD_FAN1_SPEED = "fan1-speed"
QSD_FAN2_SPEED = "fan2-speed"
QSD_FIRMWARE = "firmware"
QSD_FIRMWARE_CHECK = "firmware-check"
QSD_FIRMWARE_CONDITION = "firmware-condition"
QSD_FIRMWARE_INFO = "firmware-info"
QSD_MAC = "mac"
QSD_MESSAGE = "message"
QSD_MODEL = "model"
QSD_NEWER = "newer"
QSD_NUMBER = "number"
QSD_PORT_NUM = "port-num"
QSD_PRODUCT = "product"
QSD_PUB_DATE = "pub-date"
QSD_SERIAL = "serial"
QSD_SYSTEM_BOARD = "system-board"
QSD_SYSTEM_SENSOR = "system-sensor"
QSD_SYSTEM_TIME = "system-time"
QSD_TEMP = "temperature"
QSD_TEMP_MAX = "max-temperature"
QSD_UPTIME = "uptime"
QSD_TRUNK_NUM = "trunk-num"
QSD_VERSION = "version"

HTTP_CALL_TIMEOUT = 20

==> aioqsw-0.3.0.tar.gz: aioqsw-0.3.0/aioqsw/const.py <==
"""QNAP QSW library constants."""

API_ANOMALY = "anomaly"
API_AUTHORIZATION = "Authorization"
API_BUILD_NUMBER = "buildNumber"
API_CHIP_ID = "ChipId"
API_CI_BRANCH = "ci_branch"
API_CI_COMMIT = "ci_commit"
API_CI_PIPELINE = "ci_pipeline"
API_COMMAND = "command"
API_COMMIT_CPSS = "commit_cpss"
API_COMMIT_ISS = "commit_iss"
API_DATE = "date"
API_DESCRIPTION = "description"
API_DONE = "done"
API_DOWNLOAD_SIZE = "downloadSize"
API_DOWNLOAD_URL = "downloadURL"
API_ERROR_CODE = "error_code"
API_ERROR_MESSAGE = "error_message"
API_FAN1_SPEED = "Fan1Speed"
API_FAN2_SPEED = "Fan2Speed"
API_FCS_ERRORS = "FCSErrors"
API_FIRMWARE_URL = "firmwareURL"
API_FIRMWARE_SIZE = "firmwareSize"
API_FULL_DUPLEX = "FullDuplexStatus"
API_KEY = "key"
API_LINK = "Link"
API_LIVE = "live"
API_MAC_ADDR = "MacAddr"
API_MAX_PORT_CHANNELS = "MaxPortChannels"
API_MAX_PORTS_PER_PORT_CHANNEL = "MaxPortsPerPortChannel"
API_MAX_SWITCH_TEMP = "MaxSwitchTemp"
API_MESSAGE = "message"
API_MODEL = "Model"
API_NEWER = "newer"
API_NUMBER = "number"
API_PASSWORD = "password"
API_QSW_ID = "QSW_ID"
API_QSW_LANG = "QSW_LANG"
API_PATH = "api"
API_PATH_V1 = "api/v1"
API_PRODUCT = "Product"
API_PROGRESS = "progress"
API_PORT_NUM = "PortNum"
API_PUB_DATE = "pubDate"
API_REBOOT = "reboot"
API_RESULT = "result"
API_RX_ERRORS = "RxErrors"
API_RX_OCTETS = "RxOctets"
API_SERIAL = "SerialNumber"
API_SPEED = "Speed"
API_START_INDEX = "StartIndex"
API_STATUS = "Status"
API_SWITCH_TEMP = "SwitchTemp"
API_TRUNK_NUM = "TrunkNum"
API_TX_OCTETS = "TxOctets"
API_UPTIME = "UpTime"
API_USERNAME = "username"
API_VAL = "val"
API_VERSION = "version"

API_ERROR_PARSING_FAILED = 6

QSD_ANOMALY = "anomaly"
QSD_BUILD_NUMBER = "build-number"
QSD_CHIP_ID = "chip-id"
QSD_CI_BRANCH = "ci-branch"
QSD_CI_COMMIT = "ci-commit"
QSD_CI_PIPELINE = "ci-pipeline"
QSD_COMMIT_CPSS = "commit-cpss"
QSD_COMMIT_ISS = "commit-iss"
QSD_DATE = "date"
QSD_DATETIME = "datetime"
QSD_DESCRIPTION = "description"
QSD_DOWNLOAD_URLS = "download-urls"
QSD_FAN1_SPEED = "fan1-speed"
QSD_FAN2_SPEED = "fan2-speed"
QSD_FCS_ERRORS = "fcs-errors"
QSD_FIRMWARE = "firmware"
QSD_FIRMWARE_CHECK = "firmware-check"
QSD_FIRMWARE_CONDITION = "firmware-condition"
QSD_FIRMWARE_INFO = "firmware-info"
QSD_FULL_DUPLEX = "full-duplex"
QSD_ID = "id"
QSD_LACP_PORT_NUM = "lacp-port-num"
QSD_LACP_PORTS = "lacp-ports"
QSD_LINK = "link"
QSD_MAC = "mac"
QSD_MAX_CHANNEL_PORTS = "max-channel-ports"
QSD_MAX_CHANNELS = "max-channels"
QSD_MESSAGE = "message"
QSD_MODEL = "model"
QSD_NEWER = "newer"
QSD_NUMBER = "number"
QSD_PORT_NUM = "port-num"
QSD_PORTS = "ports"
QSD_PORTS_STATISTICS = "ports-statistics"
QSD_PORTS_STATUS = "ports-status"
QSD_PRODUCT = "product"
QSD_PUB_DATE = "pub-date"
QSD_RX_ERRORS = "rx-errors"
QSD_RX_OCTETS = "rx-octets"
QSD_RX_SPEED = "rx-speed"
QSD_TX_OCTETS = "tx-octets"
QSD_TX_SPEED = "tx-speed"
QSD_SERIAL = "serial"
QSD_SPEED = "speed"
QSD_START_ID = "start-id"
QSD_START_INDEX = "start-index"
QSD_SYSTEM_BOARD = "system-board"
QSD_SYSTEM_SENSOR = "system-sensor"
QSD_SYSTEM_TIME = "system-time"
QSD_TEMP = "temperature"
QSD_TEMP_MAX = "max-temperature"
QSD_UPTIME = "uptime"
QSD_TRUNK_NUM = "trunk-num"
QSD_VERSION = "version"

HTTP_CALL_TIMEOUT = 20
